@@ -5,7 +5,7 @@ from webspace.cms.blocks.common import EntryBlock
 
 
 class PortfoliosEntry(EntryBlock):
-    images = blocks.StreamBlock(
+    portfolios = blocks.StreamBlock(
         [
             ('portfolio', blocks.PageChooserBlock(required=False, target_model='cms.PortfolioPage')),
         ],
