@@ -30,6 +30,7 @@ TableEntry = get_class('cms.blocks.entries', 'TableEntry')
 AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
 NumbersEntry = get_class('cms.blocks.entries', 'NumbersEntry')
 FormEntry = get_class('cms.blocks.entries', 'FormEntry')
+GalleryEntry = get_class('cms.blocks.entries', 'GalleryEntry')
 SocialLinks = get_class('cms.blocks.static', 'SocialLinks')
 SocialShare = get_class('cms.blocks.static', 'SocialShare')
 
@@ -53,6 +54,7 @@ WebspaceSettings = get_model('cms', 'WebspaceSettings')
 MyDocument = get_model('cms', 'MyDocument')
 Form = get_model('cms', 'Form')
 FormField = get_model('cms', 'FormField')
+Gallery = get_model('cms', 'Gallery')
 
 
 class Command(BaseCommand):
@@ -77,6 +79,7 @@ class Command(BaseCommand):
         Form.objects.all().delete()
         FormField.objects.all().delete()
         Person.objects.all().delete()
+        Gallery.objects.all().delete()
 
         article_entry = ArticlesEntry()
         buttons_entry = ButtonsEntry()
@@ -94,6 +97,7 @@ class Command(BaseCommand):
         accordion_entry = AccordionEntry()
         numbers_entry = NumbersEntry()
         form_entry = FormEntry()
+        gallery_entry = GalleryEntry()
 
         social_links = SocialLinks()
         social_share = SocialShare()
@@ -652,6 +656,22 @@ class Command(BaseCommand):
         mocker.menu(forms_page, block_menu_id)
         mocker.add_menu(forms_page, home_page_menu_id)
 
+        # -------------------------------- Gallery --------------------------------
+
+        gallery_page = ContentPage(
+            title="Gallery",
+            slug='gallery',
+            body=json.dumps([
+                text_entry.mock(txt='<h1>Gallery</h1>', align='center'),
+                gallery_entry.mock(),
+                gallery_entry.mock(theme=constants.THEME_SPACE_INVERSE),
+                gallery_entry.mock(theme=constants.THEME_LIGHT),
+            ])
+        )
+        block_page.add_child(instance=gallery_page)
+        mocker.menu(gallery_page, block_menu_id)
+        mocker.add_menu(gallery_page, home_page_menu_id)
+
         # -------------------------------- Settings --------------------------------
 
         ws_settings = WebspaceSettings.for_site(site)
