@@ -73,8 +73,9 @@ const Carousel = {
     Array.prototype.forEach.call(elements, (el) => {
       const parent = el.parentNode;
       const theme = parent.getAttribute('class').split('theme-')[1];
-      const right = createElementFromHTML(`<img class='s-icon x2 right' src='${Icons.right[theme]}' alt='Suivant'>`);
-      const left = createElementFromHTML(`<img class='s-icon x2 left' src='${Icons.left[theme]}' alt='Précédent'>`);
+      const themeCorrected = theme === 'light' || theme === 'space' ? theme : 'space';
+      const right = createElementFromHTML(`<img class='s-icon x2 right' src='${Icons.right[themeCorrected]}' alt='Suivant'>`);
+      const left = createElementFromHTML(`<img class='s-icon x2 left' src='${Icons.left[themeCorrected]}' alt='Précédent'>`);
       const scrollOffset = 305;
       parent.appendChild(right);
       parent.appendChild(left);
