@@ -1,9 +1,9 @@
 from django.http import HttpResponse
 from django.shortcuts import render
 from django.template.loader import render_to_string
-from django.conf import settings
 
 from webspace.loader import get_model
+from webspace.bakery.models import VersionBuild
 
 IconSnippet = get_model('cms', 'IconSnippet')
 
@@ -21,14 +21,14 @@ def error_404(request, exception):
     return render(request, 'cms/pages/404.html', context, status=404)
 
 
-def worker(request):
+def worker(request, version):
     from wagtail.contrib.sitemaps.sitemap_generator import Sitemap
     return HttpResponse(render_to_string(
         'worker.js',
         {
             'request': request,
             'pages': Sitemap(request),
-            'version': settings.VERSION_WEBSPACE
+            'version': version
         }),
         content_type='application/javascript'
     )
